Index: /pykoticon/trunk/TODO
===================================================================
--- /pykoticon/trunk/TODO (revision 73)
+++ /pykoticon/trunk/TODO (revision 73)
@@ -0,0 +1,26 @@
+# $Id$
+
+PyKotIcon - an end-user companion for PyKota
+
+(c) 2005 Jerome Alet <alet@librelogiciel.com>
+This program is free software; you can redistribute it and/or modify
+it under the terms of the GNU General Public License as published by
+the Free Software Foundation; either version 2 of the License, or
+(at your option) any later version.
+
+This program is distributed in the hope that it will be useful,
+but WITHOUT ANY WARRANTY; without even the implied warranty of
+MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+GNU General Public License for more details.
+
+You should have received a copy of the GNU General Public License
+along with this program; if not, write to the Free Software
+Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
+
+============================================================
+
+TODO, in no particular order :
+
+============================================================
+
+Please e-mail bugs to: alet@librelogiciel.com (Jerome Alet)
Index: /pykoticon/trunk/clean.sh
===================================================================
--- /pykoticon/trunk/clean.sh (revision 73)
+++ /pykoticon/trunk/clean.sh (revision 73)
@@ -0,0 +1,28 @@
+#! /bin/sh
+#
+# PyKotIcon - an end-user companion for PyKota
+#
+# (c) 2005 Jerome Alet <alet@librelogiciel.com>
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+# 
+# You should have received a copy of the GNU General Public License
+# along with this program; if not, write to the Free Software
+# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
+#
+# $Id$
+
+# Use this to clean the tree from temporary files
+
+find . -name "*.bak" -exec rm -f {} \;
+find . -name "*~" -exec rm -f {} \;
+find . -name "*.pyc" -exec rm -f {} \;
+find . -name "*.pyo" -exec rm -f {} \;
+find . -name "*.jem" -exec rm -f {} \;
Index: /pykoticon/trunk/NEWS
===================================================================
--- /pykoticon/trunk/NEWS (revision 73)
+++ /pykoticon/trunk/NEWS (revision 73)
@@ -0,0 +1,23 @@
+# $Id$
+
+PyKotIcon - an end-user companion for PyKota
+
+(c) 2005 Jerome Alet <alet@librelogiciel.com>
+This program is free software; you can redistribute it and/or modify
+it under the terms of the GNU General Public License as published by
+the Free Software Foundation; either version 2 of the License, or
+(at your option) any later version.
+
+This program is distributed in the hope that it will be useful,
+but WITHOUT ANY WARRANTY; without even the implied warranty of
+MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+GNU General Public License for more details.
+
+You should have received a copy of the GNU General Public License
+along with this program; if not, write to the Free Software
+Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
+
+============================================================
+
+PyKotIcon NEWS :
+
Index: /pykoticon/trunk/CREDITS
===================================================================
--- /pykoticon/trunk/CREDITS (revision 73)
+++ /pykoticon/trunk/CREDITS (revision 73)
@@ -0,0 +1,20 @@
+# $Id$
+
+PyKotIcon - an end-user companion for PyKota
+
+(c) 2005 Jerome Alet <alet@librelogiciel.com>
+This program is free software; you can redistribute it and/or modify
+it under the terms of the GNU General Public License as published by
+the Free Software Foundation; either version 2 of the License, or
+(at your option) any later version.
+
+This program is distributed in the hope that it will be useful,
+but WITHOUT ANY WARRANTY; without even the implied warranty of
+MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+GNU General Public License for more details.
+
+You should have received a copy of the GNU General Public License
+along with this program; if not, write to the Free Software
+Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
+
+============================================================
Index: /pykoticon/trunk/README
===================================================================
--- /pykoticon/trunk/README (revision 71)
+++ /pykoticon/trunk/README (revision 73)
@@ -1,5 +1,5 @@
 # $Id$
 
-PyKotIcon - An end user companion to PyKota
+PyKotIcon - an end-user companion for PyKota
 
 (c) 2005 Jerome Alet <alet@librelogiciel.com>

Index: /pykoticon/trunk/setup.py
===================================================================
--- /pykoticon/trunk/setup.py (revision 72)
+++ /pykoticon/trunk/setup.py (revision 73)
@@ -2,5 +2,5 @@
 # -*- coding: ISO-8859-15 -*-
 
 # PyKotIcon - Windows System Tray Icon for PyKota
 #
 # (c) 2003-2004 Jerome Alet <alet@librelogiciel.com>
@@ -24,11 +24,27 @@
 
 from distutils.core import setup
+import sys
 import os
-import py2exe
 import glob
+try :
+    import py2exe
+except ImportError :
+    if sys.platform == "win32" :
+        sys.stderr.write("py2exe is not installed ! ABORTING.\n")
+        sys.exit(-1)
+    else :    
+        withPy2EXE = 0
+else :        
+    withPy2EXE = 1
 
-setup(
-       name="pykoticon",
-       windows=[os.path.join("bin", "pykoticon")],
-       data_files=[("icons", glob.glob(os.path.join("icons", "*.ico"))),
-                  ])
+version = "0.1"
+
+setup(name = "pykoticon", version = version,
+      license = "GNU GPL",
+      description = "an end-user companion for PyKota",
+      author = "Jerome Alet",
+      author_email = "alet@librelogiciel.com",
+      url = "http://www.librelogiciel.com/software/",
+      windows=[os.path.join("bin", "pykoticon")],
+      scripts=[os.path.join("bin", "pykoticon")],
+      data_files=[("icons", glob.glob(os.path.join("icons", "*.ico")))])
@@ -2,5 +2,5 @@
 # -*- coding: ISO-8859-15 -*-
 
-# PyKotIcon - Windows System Tray Icon for PyKota
+# PyKotIcon - an end-user companion for PyKota
 #
 # (c) 2003-2004 Jerome Alet <alet@librelogiciel.com>